@@ -4,11 +4,11 @@ test_that("Computation across 3 threads", {
   fun <- function(x) {
     return(x^2)
   }
-
+  
   cluster <- makeCluster(numberOfThreads = 3)
   x <- clusterApply(cluster, 1:10, fun)
   stopCluster(cluster)
-
+  
   expect_equal(length(x), 10)
   expect_equal(sum(unlist(x)), sum((1:10)^2))
 })
@@ -18,13 +18,13 @@ test_that("Create a cluster of nodes for parallel computation", {
     "test"
   }
   ParallelLogger:::registerDefaultHandlers()
-
+  
   summary(f())
-
+  
   cluster <- ParallelLogger::makeCluster(2)
   res <- ParallelLogger::clusterApply(cluster, f(), summary)
   ParallelLogger::stopCluster(cluster)
-
+  
   expect_equal(length(res), 1)
 })
 
@@ -33,12 +33,12 @@ test_that("Test require package", {
     expr = {
       package <- "test invalid pkg for failing"
       cluster <- ParallelLogger::makeCluster(1)
-
+      
       res <- capture.output(capture.output(out <- ParallelLogger::clusterRequire(cluster, package), type = "message"), type = "output")
-
+      
       expectLoading <- sprintf("Loading required package: %s", package)
       expectWarning <- sprintf("Warning: there is no package called ‘%s’", package)
-
+      
       expect_equal(out, FALSE)
       expect_true(grepl(expectLoading, res[1]))
       expect_true(grepl(expectWarning, res[2]))
@@ -46,10 +46,10 @@ test_that("Test require package", {
     error = function(e) {
     },
     warning = function(w) {
-
+      
     },
     finally = {
-
+      
     }
   )
 })
@@ -78,7 +78,10 @@ test_that("Test getThreadNumber", {
 
 
 test_that("Test getPhysicalMemory", {
-  # Cannot determine physical memory on CRAN's Debian machine, so skip there:
-  skip_on_cran()
+  # Very dirty, but skip_on_cran() doesn't work on CRAN's M1mac machine
+  # (see https://github.com/r-lib/testthat/issues/2074)
+  if (Sys.getenv("CDM5_POSTGRESQL_CDM_SCHEMA", unset = "") == "") {
+    skip("Not an OHDSI machine, so skipped test for getPhysicalMemory()")
+  }
   expect_false(is.na(getPhysicalMemory()))
 })
